import { Genre, Movie } from './index';
export interface ProductionCompany {
    id: number;
    logo_path: string;
    name: string;
    origin_country: string;
}
export interface ProductionCountry {
    iso_3166_1: string;
    name: string;
}
export interface SpokenLanguage {
    iso_639_1: string;
    name: string;
}
export interface MovieDetails {
    adult: boolean;
    backdrop_path: string;
    belongs_to_collection?: any;
    budget: number;
    genres: Genre[];
    homepage: string;
    id: number;
    imdb_id: string;
    original_language: string;
    original_title: string;
    overview: string;
    popularity: number;
    poster_path?: any;
    production_companies: ProductionCompany[];
    production_countries: ProductionCountry[];
    release_date: string;
    revenue: number;
    runtime: number;
    spoken_languages: SpokenLanguage[];
    status: string;
    tagline: string;
    title: string;
    video: boolean;
    vote_average: number;
    vote_count: number;
}
export interface Title {
    iso_3166_1: string;
    title: string;
    type: string;
}
export interface AlternativeTitles {
    id: number;
    titles: Title[];
}
export interface Cast {
    adult: boolean;
    gender: number;
    id: number;
    known_for_department: string;
    name: string;
    original_name: string;
    popularity: number;
    profile_path: string;
    cast_id: number;
    character: string;
    credit_id: string;
    order: number;
}
export interface Crew {
    adult: boolean;
    gender: number;
    id: number;
    known_for_department: string;
    name: string;
    original_name: string;
    popularity: number;
    profile_path: string;
    credit_id: string;
    department: string;
    job: string;
}
export interface Credits {
    id: number;
    cast: Cast[];
    crew: Crew[];
}
export interface Backdrop {
    aspect_ratio: number;
    file_path: string;
    height: number;
    iso_639_1?: any;
    vote_average: number;
    vote_count: number;
    width: number;
}
export interface Poster {
    aspect_ratio: number;
    file_path: string;
    height: number;
    iso_639_1: string;
    vote_average: number;
    vote_count: number;
    width: number;
}
export interface Images {
    id: number;
    backdrops: Backdrop[];
    posters: Poster[];
}
export interface Video {
    id: string;
    iso_639_1: string;
    iso_3166_1: string;
    key: string;
    name: string;
    site: string;
    size: number;
    type: string;
}
export interface Videos {
    id: number;
    results: Video[];
}
export interface Keywords {
    id: number;
    keywords: Array<{
        id: number;
        name: string;
    }>;
}
export interface ReleaseDate {
    certification: string;
    iso_639_1: string;
    release_date: Date;
    type: number;
    note: string;
}
export interface ReleaseDateResult {
    iso_3166_1: string;
    release_dates: ReleaseDate[];
}
export interface ReleaseDates {
    id: number;
    results: ReleaseDateResult[];
}
export interface SimilarMovies {
    page: number;
    results: Movie[];
    total_pages: number;
    total_results: number;
}
export interface AuthorDetails {
    name: string;
    username: string;
    avatar_path: string;
    rating?: number;
}
export interface Review {
    author: string;
    author_details: AuthorDetails;
    content: string;
    created_at: Date;
    id: string;
    updated_at: Date;
    url: string;
}
export interface MovieReviews {
    id: number;
    page: number;
    results: Review[];
    total_pages: number;
    total_results: number;
}
export interface TranslationData {
    title: string;
    overview: string;
    homepage: string;
}
export interface Translation {
    iso_3166_1: string;
    iso_639_1: string;
    name: string;
    english_name: string;
    data: TranslationData;
}
export interface MovieTranslations {
    id: number;
    translations: Translation[];
}
export interface MovieList {
    description: string;
    favorite_count: number;
    id: number;
    item_count: number;
    iso_639_1: string;
    list_type: string;
    name: string;
    poster_path: string;
}
export interface MovieLists {
    id: number;
    page: number;
    results: MovieList[];
    total_pages: number;
    total_results: number;
}
export interface MovieChangeItem {
    id: string;
    action: string;
    time: string;
    iso_639_1: string;
    value: string;
    original_value: string;
}
export interface MovieChange {
    key: string;
    items: MovieChangeItem[];
}
export interface MovieChanges {
    changes: MovieChange[];
}
export interface MovieRecommendation {
    adult: boolean;
    backdrop_path?: any;
    genre_ids: number[];
    id: number;
    original_language: string;
    original_title: string;
    overview: string;
    release_date: string;
    poster_path?: any;
    popularity: number;
    title: string;
    video: boolean;
    vote_average: number;
    vote_count: number;
}
export interface MovieRecommendations {
    page: number;
    results: MovieRecommendation[];
    total_pages: number;
    total_results: number;
}
export interface LatestMovie {
    adult: boolean;
    backdrop_path?: any;
    belongs_to_collection?: any;
    budget: number;
    genres: Genre[];
    homepage: string;
    id: number;
    imdb_id: string;
    original_language: string;
    original_title: string;
    overview: string;
    popularity: number;
    poster_path: string;
    production_companies: any[];
    production_countries: any[];
    release_date: string;
    revenue: number;
    runtime: number;
    spoken_languages: any[];
    status: string;
    tagline: string;
    title: string;
    video: boolean;
    vote_average: number;
    vote_count: number;
}
export interface Dates {
    maximum: string;
    minimum: string;
}
export interface MoviesPlayingNow {
    page: number;
    results: Movie[];
    dates: Dates;
    total_pages: number;
    total_results: number;
}
export interface PopularMovies {
    page: number;
    results: Movie[];
    total_results: number;
    total_pages: number;
}
export interface TopRatedMovies {
    page: number;
    results: Movie[];
    total_results: number;
    total_pages: number;
}
export interface UpcomingMovies {
    page: number;
    results: Movie[];
    total_results: number;
    total_pages: number;
}
